#!/bin/sh
#
# The ant taks wlconfig will automatically boostrap the domain and create start scripts.
# However those won't start pointbase for you automatically, so these get copied and have 
# @WL_HOME@ replaced by roller.home/setup/build.xml into roller.home/domain directory 
#
# You should use these instead of those to start WebLogic.
#
#
# ****************************************************************************
# This script is used to start WebLogic Server for the domain in the current 
# working directory.  This script simply sets the SERVER_NAME variable 
# and calls the startWLS.sh script under {WL_HOME}/server/bin.
#
# To create your own start script for your domain, all you need to set is 
# SERVER_NAME, then start the server.
#
# Other variables that startWLS takes are:
#
# WLS_USER       - cleartext user for server startup
# WLS_PW         - cleartext password for server startup
# STARTMODE      - Set to true for production mode servers, false for 
#                  development mode
# JAVA_OPTIONS   - Java command-line options for running the server. (These
#                  will be tagged on to the end of the JAVA_VM and MEM_ARGS)
# JAVA_VM        - The java arg specifying the VM to run.  (i.e. -server, 
#                  -hotspot, etc.)
# MEM_ARGS       - The variable to override the standard memory arguments
#                  passed to java
#
# For additional information, refer to the WebLogic Server Administration Guide
# in the BEA online documentation at (http://e-docs.bea.com).
# ****************************************************************************

# set up WL_HOME, the root directory of your WebLogic installation
WL_HOME=@WL_HOME@

# set up common environment
. "${WL_HOME}//common//bin//commEnv.sh"

# Set SERVER_NAME to the name of the server you wish to start up.
SERVER_NAME="rollerserver"

# Set WLS_USER equal to your system username and WLS_PW equal  
# to your system password for no username and password prompt 
# during server startup.  Both are required to bypass the startup
# prompt.
WLS_USER=
WLS_PW=

# Set Production Mode.  When this is set to true, the server starts up in 
# production mode.  When set to false, the server starts up in development 
# mode.  If it is not set, it will default to false.
STARTMODE=""

# Set JAVA_OPTIONS to the java flags you want to pass to the vm.  If there 
# are more than one, include quotes around them.  For instance: 
# JAVA_OPTIONS="-Dweblogic.attribute=value -Djava.attribute=value"

# Over-write JVM arguments initialized in commEnv.sh
case $JAVA_VENDOR in
BEA)
MEM_ARGS=
JAVA_VM=
;;
IBM)
MEM_ARGS=
JAVA_VM=
;;
HP)
MEM_ARGS=
JAVA_VM=
;;
SUN)
MEM_ARGS=
JAVA_VM=
;;
*)
;;
esac



# Reset number of open file descriptors in the current process
# This function is defined in commEnv.sh
resetFd

# Start WebLogic server
CLASSPATH="${WEBLOGIC_CLASSPATH}${CLASSPATHSEP}${POINTBASE_CLASSPATH}${CLASSPATHSEP}${JAVA_HOME}/jre/lib/rt.jar${CLASSPATHSEP}${WL_HOME}/server/lib/webservices.jar${CLASSPATHSEP}${CLASSPATH}${CLASSPATHSEP}./mysql-connector-java-3.0.8-stable-bin.jar"
export CLASSPATH

# Start PointBase 4.3.  PointBase will be killed when the server is shutdown.
unset POINTBASE_PID
"$JAVA_HOME/bin/java" ${JAVA_OPTIONS} com.pointbase.net.netServer /port:9092 /d:3 /noconsole /pointbase.ini="pointbase.ini" > pointbase.log 2>&1 &
POINTBASE_PID=${!}

# trap SIGINT, this function is defined in commEnv.sh
trapSIGINT

echo
echo "POINTBASE DATABASE HAS BEEN STARTED, IT'S PID IS ${POINTBASE_PID}!"
echo
#****************************************************************************


java ${JAVA_VM} ${MEM_ARGS} ${JAVA_OPTIONS} -Dweblogic.Name=${SERVER_NAME} -Dweblogic.management.username=${WLS_USER} -Dweblogic.management.password=${WLS_PW} -Dweblogic.ProductionModeEnabled=${STARTMODE} -Djava.security.policy="${WL_HOME}/server/lib/weblogic.policy" weblogic.Server
