
-- This is the raw DB creation script, do not try to run it.
-- The build script uses substitution to make DB specific versions.


-- *****************************************************
-- Create the tables and indices
drop table rolleruser;
drop table role;
drop table page;
drop table website;
drop table folder;
drop table bookmark;
drop table weblogcategory;
drop table weblogentry;
drop table newsfeed;
drop table comment;
drop table referer;

create table rolleruser ( 
    id              varchar(48) not null primary key,
    username        varchar(255) not null,
    password        varchar(255) not null,
    fullname        varchar(255) not null,
    emailaddress    varchar(255) not null
);
alter table rolleruser add constraint rolleruser_username_uq unique ( username );


create table role (
    id               varchar(48) not null primary key,
    role             varchar(255) not null,
    username         varchar(255) not null,
    userid           varchar(48) not null
);
create index userid_index on role( userid );


create table page (
    id              varchar(48)  not null primary key,
    name            varchar(255)  not null,
    description     varchar(255)  null,
    link            varchar(255)  null,
    websiteid       varchar(255)  not null,
    template        text not null,
    updatetime      timestamp     not null
);


create table website (
    id               varchar(48) not null primary key,
    name             varchar(255) not null,
    description      varchar(255) not null,
    userid           varchar(48) not null,
    defaultpageid    varchar(48) default 0 not null,
    weblogdayid      varchar(48) not null,
    ignorewords      text,
    enablebloggerapi boolean default false not null,
    editorpage       varchar(255) null,
    bloggercatid     varchar(48) null,
    allowcomments    boolean default true not null
); 
create index userid_index on website( userid );

--Modify the websiteid of this folder to be the same size as the pk of website (id)
create table folder (
    id               varchar(48) not null primary key,
    name             varchar(255) not null,
    description      varchar(255) null,
    parentid         varchar(48) null,
    websiteid        varchar(48) not null
);
create index webisteid_index on folder( websiteid );
create index parentid_index on folder( parentid );


create table bookmark (
    id               varchar(48) not null primary key,
    folderid         varchar(48) not null,
    name             varchar(255) not null,
    description      varchar(255) null,
    url              varchar(255) not null,
    weight           integer default 0 not null,
    priority         integer default 100 not null,
    image            varchar(255) null,
    feedurl          varchar(255) null
);
create index folderid_index on bookmark( folderid );


create table weblogcategory (
    id               varchar(48) not null primary key,
    name             varchar(255) not null,
    description      varchar(255) null,
    websiteid        varchar(48) not null,
    image            varchar(255) null
);
create index websiteid_index on weblogcategory( websiteid );


create table weblogentry (
    id              varchar(48)  not null primary key,
    anchor          varchar(255)  not null,
    title           varchar(255)  not null,
    text            text not null,
    pubtime         timestamp     not null,
    updatetime      timestamp     not null,
    websiteid       varchar(48)  not null,
    categoryid      varchar(48)  not null,
    publishentry    boolean default true not null
);
create index websiteid_index on weblogentry( websiteid );
create index categoryid_index on weblogentry( categoryid );


create table newsfeed (
    id              varchar(48) not null primary key,
    name            varchar(255) not null,
    description     varchar(255) not null,
    link            varchar(255) not null,
    websiteid       varchar(48) not null
);
create index websiteid_index on newsfeed( websiteid );


create table comment (
    id      varchar(48) not null primary key,
    entryid varchar(48) not null,
    name    varchar(255) null,
    email   varchar(255) null,
    url     varchar(255) null,
    content text null,
    posttime timestamp   not null
);
create index entryid_index on comment( entryid );


-- Referer tracks URLs that refer to websites and entries
create table referer (
    id        varchar(48) not null primary key,
    websiteid varchar(48) not null,
    entryid   varchar(48),
    datestr   varchar(10),
    refurl    varchar(255) not null,    
    refpermalink varchar(255),    
    reftime   timestamp,
    requrl    varchar(255),    
    title     varchar(255),    
    excerpt   text null,
    dayhits   integer default 0 not null,
    totalhits integer default 0 not null,    
    visible   boolean default false not null,
    duplicate boolean default false not null
);
create index websiteid_index on referer( websiteid );
create index entryid_index on referer( entryid );

-- *****************************************************
-- Now add the foreign key relationships

-- user, role and website 

alter table website add constraint website_userid_fk 
    foreign key ( userid ) references rolleruser ( id );

alter table role add constraint role_userid_fk 
    foreign key ( userid ) references rolleruser( id );

-- entry, category, comment

alter table weblogentry add constraint weblogentry_websiteid_fk 
    foreign key ( websiteid ) references website( id );
    
alter table weblogentry add constraint weblogentry_categoryid_fk 
    foreign key ( categoryid ) references weblogcategory( id );
    
alter table weblogcategory add constraint weblogcategory_websiteid_fk 
    foreign key ( websiteid ) references website( id );

alter table comment add constraint comment_entryid_fk 
    foreign key ( entryid ) references weblogentry( id );
       
-- referer

alter table referer add constraint referer_entryid_fk 
    foreign key ( entryid ) references weblogentry( id );

alter table referer add constraint referer_entryid_fk 
    foreign key ( websiteid ) references website( id );
        
alter table referer add constraint referer_websiteid_fk 
    foreign key ( websiteid ) references website( id );
    

    
-- folder and bookmark

alter table folder add constraint folder_websiteid_fk 
    foreign key ( websiteid ) references website( id );
    
alter table folder add constraint referer_websiteid_fk 
    foreign key ( websiteid ) references website( id );
    
alter table folder add constraint folder_parentid_fk 
    foreign key ( parentid ) references folder( id );

alter table bookmark add constraint bookmark_folderid_fk 
    foreign key ( folderid ) references folder( id );

-- newsfeed

alter table newsfeed add constraint newsfeed_websiteid_fk 
    foreign key ( websiteid ) references website( id );

-- THE FOLLOWING CONSTRAINTS CAN NOT BE SUPPORTED FOR IMPORTING new-user.xml
-- alter table website add constraint website_defaultpageid_fk foreign key ( defaultpageid ) references page ( id );
-- alter table website add constraint website_weblogdayid_fk foreign key ( weblogdayid ) references page ( id );
-- alter table page add constraint page_websiteid_fk foreign key ( websiteid ) references website( id );

-- MedRec - Data Definition Language

-- Drop sequences

--DROP TABLE address_seq;
--DROP TABLE patient_seq;
--DROP TABLE physician_seq;
--DROP TABLE prescription_seq;
--DROP TABLE record_seq;
--DROP TABLE vital_signs_seq;
--
---- Drop Medrec tables
--DROP TABLE address;
--DROP TABLE groups;
--DROP TABLE patient;
--DROP TABLE physician;
--DROP TABLE prescription;
--DROP TABLE record;
--DROP TABLE medrec_user;
--DROP TABLE vital_signs;
--
---- Create sequence
--CREATE TABLE address_seq (sequence INTEGER);
--CREATE TABLE patient_seq (sequence INTEGER);
--CREATE TABLE physician_seq (sequence INTEGER);
--CREATE TABLE prescription_seq (sequence INTEGER);
--CREATE TABLE record_seq (sequence INTEGER);
--CREATE TABLE vital_signs_seq (sequence INTEGER);
--
---- Create Medrec tables
--CREATE TABLE address	(
-- id	INTEGER NOT NULL CONSTRAINT address_pk PRIMARY KEY,
-- street1	VARCHAR(60) NOT NULL,
-- street2	VARCHAR(60),
-- city	VARCHAR(60) NOT NULL,
-- state	VARCHAR(2) NOT NULL,
-- zip	VARCHAR(10) NOT NULL,
-- country VARCHAR(50) NOT NULL
--);
--
--CREATE TABLE groups	(
-- username	VARCHAR(60) NOT NULL,
-- group_name	VARCHAR(60) NOT NULL
--);
--
--CREATE TABLE medrec_user (
--  username VARCHAR(45) NOT NULL CONSTRAINT username_pk PRIMARY KEY,
--  password VARCHAR(10) NOT NULL,
--  status VARCHAR(15) NOT NULL
--);
--
--CREATE TABLE patient	(
--  id	INTEGER CONSTRAINT patient_pk PRIMARY KEY,
--  first_name	VARCHAR(60) NOT NULL,
--  middle_name	VARCHAR(60),
--  last_name	VARCHAR(60) NOT NULL,
--  dob	DATE NOT NULL,
--  gender    VARCHAR(6) NOT NULL,
--  ssn	VARCHAR(9) NOT NULL,
--  address_id INTEGER NOT NULL,
--  phone	VARCHAR(15),
--  email	VARCHAR(60) NOT NULL
--);
--
--CREATE TABLE physician	(
-- id	INT NOT NULL CONSTRAINT physician_pk PRIMARY KEY,
-- first_name	VARCHAR(60) NOT NULL,
-- middle_name	VARCHAR(60),
-- last_name	VARCHAR(60) NOT NULL,
-- address_id INTEGER NOT NULL,
-- phone	VARCHAR(15),
-- email	VARCHAR(60)
--);
--
--CREATE TABLE prescription	(
-- id INTEGER NOT NULL CONSTRAINT prescription_pk PRIMARY KEY,
-- pat_id	INTEGER NOT NULL,
-- issuing_phys_id INTEGER NOT NULL,
-- date_prescribed DATE NOT NULL,
-- drug	VARCHAR(80) NOT NULL,
-- record_id INTEGER  NOT NULL,
-- dosage	VARCHAR(30) NOT NULL,
-- frequency	VARCHAR(30),
-- refills_remaining	INTEGER,
-- instructions	VARCHAR(255)
--);
--
--CREATE TABLE record	(
-- id	INTEGER NOT NULL CONSTRAINT record_pk PRIMARY KEY,
-- pat_id	INTEGER NOT NULL,
-- phys_id	INTEGER NOT NULL,
-- record_date	DATE NOT NULL,
-- vital_id INTEGER  NOT NULL,
-- symptoms	VARCHAR(255) NOT NULL,
-- diagnosis	VARCHAR(255),
-- notes	VARCHAR(255)
--);
--
--CREATE TABLE vital_signs	(
-- id	INTEGER NOT NULL CONSTRAINT vital_signs_pk PRIMARY KEY,
-- temperature VARCHAR(4),
-- blood_pressure	VARCHAR(10),
-- pulse	VARCHAR(10),
-- weight INTEGER,
-- height INTEGER
--);
--
--COMMIT;
--